@@ -6,45 +6,52 @@ basic actions on behalf of the forum application
 """
 import os
 import platform
+import sys
+import traceback
 
-VERSION = (0, 11, 2)
+VERSION = (0, 11, 4)
 
-default_app_config = 'askbot.apps.AskbotConfig'
+default_app_config = 'askbot.apps.AskbotConfig' #pylint: disable=invalid-name
 
 #keys are module names used by python imports,
 #values - the package qualifier to use for pip
 REQUIREMENTS = {
-    'appconf': 'django-appconf==1.0.3',
+    'aiohttp': 'aiohttp<4.0',
+    'appconf': 'django-appconf==1.0.5',
     'akismet': 'akismet==1.0.1',
     'avatar': 'django-avatar>=4.0',
+    'bleach': 'bleach==5.0.1',
     'bs4': 'beautifulsoup4<=4.7.1',
     'compressor': 'django-compressor>=2.0,<=2.4',
-    'django': 'django>=1.11,<3.0',
+    'celery': 'celery==5.2.7',
+    'django': 'django>=1.11,<4.0',
     'django_countries': 'django-countries>=3.3',
     'django_jinja': 'django-jinja>=2.0',
-    'celery': 'celery>=4.0,<5.0',
-    'followit': 'django-followit==0.4.1',
-    'html5lib': 'html5lib==0.9999999',
-    'jinja2': 'Jinja2>=2.10',
+    'followit': 'django-followit==0.5.0',
+    'html5lib': 'html5lib==1.1',
+    'jinja2': 'Jinja2>=2.10,<3.1',
     'jsonfield': 'jsonfield>=2.0.0',
     'jwt': 'pyjwt<=1.7.1',
     'keyedcache': 'django-keyedcache3>=1.5.1',
-    'livesettings': 'django-livesettings3==1.4.20',
+    'livesettings': 'django-livesettings3==1.5.1',
     'markdown2': 'markdown2<=2.3.9',
+    'markupsafe': 'markupsafe',
     'mock': 'mock==3.0.5',
     'oauth2': 'oauth2<=1.9.0.post1',
     'openid': 'python-openid2>=3.0',
-    'picklefield': 'django-picklefield>=1.0.0',
+    'picklefield': 'django-picklefield>=1.0.0,<=3.0.1',
     'pytz': 'pytz',
     'captcha': 'django-recaptcha>=1.0.3,<=1.3.0',
     'cas': 'python-cas>=1.4.0,<1.6',
+    'okta_jwt_verifier': 'okta-jwt-verifier==0.2.3',
     'responses': 'responses>=0.9.0',
     'requests_oauthlib': 'requests-oauthlib>=1.2.0',
     'requirements': 'requirements-parser>=0.2.0',
-    'robots': 'django-robots>=3.1',
+    'robots': 'django-robots>=3.1,<5.0',
     'regex': 'regex',
-    'tinymce': 'django-tinymce>=2.8.0',
-    'unidecode': 'unidecode'
+    'tinymce': 'django-tinymce==2.8.0',
+    'unidecode': 'unidecode',
+    'urllib3': 'urllib3<1.27,>=1.21.1'
 }
 
 def get_install_directory():
@@ -62,7 +69,7 @@ def get_askbot_module_path(relative_path):
     and must not start with a slash
     """
     root_dir = get_install_directory()
-    assert(relative_path[0] != 0)
+    assert relative_path[0] != 0
     path_bits = relative_path.split('/')
     return os.path.join(root_dir, *path_bits)
 
@@ -79,18 +86,16 @@ def get_database_engine_name():
     independently of the version of django.
     This was required for the django 1.0 -> 1.1 migration
     """
-    from django.conf import settings as django_settings
+    from django.conf import settings as django_settings #pylint: disable=import-outside-toplevel
     return django_settings.DATABASES['default']['ENGINE']
 
 
 def get_lang_mode():
-    from django.conf import settings as django_settings
+    from django.conf import settings as django_settings #pylint: disable=import-outside-toplevel
     try:
         return django_settings.ASKBOT_LANGUAGE_MODE
-    except:
-        import traceback
+    except AttributeError:
         traceback.print_stack()
-        import sys
         sys.exit()
 
 
