@@ -25,6 +25,8 @@ CLOSE_REASONS = (
     (7, _('question contains offensive or malicious remarks')),
     (8, _('spam or advertising')),
     (9, _('too localized')),
+    (10, _('question is considered as answered')),
+    (11, _('closed as inactive'))
 )
 
 LONG_TIME = 60*60*24*30 #30 days is a lot of time
@@ -283,6 +285,13 @@ TYPE_ACTIVITY = (
     )
 )
 
+SIDEBAR_AVATARS_BLOCK_ACTIVITY_TYPES = (
+    TYPE_ACTIVITY_ASK_QUESTION,
+    TYPE_ACTIVITY_ANSWER,
+    TYPE_ACTIVITY_UPDATE_QUESTION,
+    TYPE_ACTIVITY_UPDATE_ANSWER
+)
+
 MODERATED_EDIT_ACTIVITY_TYPES = (
     TYPE_ACTIVITY_MODERATED_NEW_POST,
     TYPE_ACTIVITY_MODERATED_POST_EDIT
@@ -407,9 +416,7 @@ VOTE_TYPES_INVALIDATE_CACHE = (
 #
 VOTE_TYPES = {
     VOTE_ACCEPT_ANSWER: ('answer', ),
-
-    VOTE_FAVORITE: None,  # TODO: not handled in the view
-
+    VOTE_FAVORITE: None, #maybe not used
     # args: (post_type, vote_directiom)
     VOTE_UPVOTE_QUESTION: ('question', 'up'),
     VOTE_DOWNVOTE_QUESTION: ('question', 'down'),
@@ -438,7 +445,7 @@ EXCLUDE_IGNORED = 1
 INCLUDE_INTERESTING = 2
 INCLUDE_SUBSCRIBED = 3
 TAG_DISPLAY_FILTER_STRATEGY_MINIMAL_CHOICES = (
-    (INCLUDE_ALL, _('show all tags')),
+    (INCLUDE_ALL, _('all tags')),
     (EXCLUDE_IGNORED, _('exclude ignored tags')),
     (INCLUDE_INTERESTING, _('only interesting tags'))
 )
@@ -447,19 +454,19 @@ TAG_DISPLAY_FILTER_STRATEGY_CHOICES = \
     ((INCLUDE_SUBSCRIBED, _('only subscribed tags')),)
 
 TAG_EMAIL_FILTER_SIMPLE_STRATEGY_CHOICES = (
-    (INCLUDE_ALL, _('subscribe to all tags')),
+    (INCLUDE_ALL, _('all tags')),
     (EXCLUDE_IGNORED, _('exclude ignored tags')),
     (INCLUDE_INTERESTING, _('only interesting tags')),
 )
 
 TAG_EMAIL_FILTER_ADVANCED_STRATEGY_CHOICES = (
-    (INCLUDE_ALL, _('subscribe to all tags')),
+    (INCLUDE_ALL, _('all tags')),
     (EXCLUDE_IGNORED, _('exclude ignored tags')),
     (INCLUDE_SUBSCRIBED, _('only subscribed tags')),
 )
 
 TAG_EMAIL_FILTER_FULL_STRATEGY_CHOICES = (
-    (INCLUDE_ALL, _('subscribe to all tags')),
+    (INCLUDE_ALL, _('all tags')),
     (EXCLUDE_IGNORED, _('exclude ignored tags')),
     (INCLUDE_INTERESTING, _('only interesting tags')),
     (INCLUDE_SUBSCRIBED, _('only subscribed tags')),
@@ -509,7 +516,8 @@ USER_STATUS_CHOICES = (
     ('w', _('watched')), #regular user placed on the moderation watch
     ('s', _('suspended')), #suspended user who cannot post new stuff
     ('b', _('blocked')), #blocked
-    ('t', _('terminated')) #terminated account, personal data deleted, content anonymized and retained
+    #terminated account, personal data deleted, content anonymized and retained
+    ('t', _('terminated'))
 )
 DEFAULT_USER_STATUS = 'w'
 
@@ -548,9 +556,9 @@ BADGE_TYPE_CHOICES = ((GOLD_BADGE, _('gold')),
                       (BRONZE_BADGE, _('bronze')))
 
 BADGE_CSS_CLASSES = {
-    GOLD_BADGE: 'badge1',
-    SILVER_BADGE: 'badge2',
-    BRONZE_BADGE: 'badge3',
+    GOLD_BADGE: 'badge with-gold-badge-icon',
+    SILVER_BADGE: 'badge with-silver-badge-icon',
+    BRONZE_BADGE: 'badge with-bronze-badge-icon',
 }
 BADGE_DISPLAY_SYMBOL = '&#9679;'
 
