@@ -11,13 +11,16 @@ from django.db.models import signals
 from django.template import Context
 from django.template.loader import get_template
 from django.utils import timezone
-from django.utils.importlib import import_module
+try:
+    from importlib import import_module
+except ImportError:
+    from django.utils.importlib import import_module
 from django.utils.translation import ugettext as _
 from askbot.deps.group_messaging.signals import response_created
 from askbot.deps.group_messaging.signals import thread_created
 import copy
 import datetime
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
 MAX_HEADLINE_LENGTH = 80
 MAX_SUBJECT_LINE_LENGTH = 30
@@ -71,8 +74,8 @@ class LastVisitTime(models.Model):
     """just remembers when a user has
     last visited a given thread
     """
-    user = models.ForeignKey(User)
-    message = models.ForeignKey('Message')
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
+    message = models.ForeignKey('Message', on_delete=models.CASCADE)
     at = models.DateTimeField(auto_now_add=True)
 
     class Meta:
@@ -99,7 +102,7 @@ class SenderList(models.Model):
     sender list is populated automatically
     as new messages are created
     """
-    recipient = models.OneToOneField(Group)
+    recipient = models.OneToOneField(Group, on_delete=models.CASCADE)
     senders = models.ManyToManyField(User)
     objects = SenderListManager()
 
@@ -125,8 +128,8 @@ class MessageMemo(models.Model):
         (ARCHIVED, 'archived'),
         (DELETED, 'deleted')
     )
-    user = models.ForeignKey(User)
-    message = models.ForeignKey('Message', related_name='memos')
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
+    message = models.ForeignKey('Message', related_name='memos', on_delete=models.CASCADE)
     status = models.SmallIntegerField(
             choices=STATUS_CHOICES, default=SEEN
         )
@@ -299,7 +302,7 @@ class Message(models.Model):
         default=STORED,
     )
 
-    sender = models.ForeignKey(User, related_name='group_messaging_sent_messages')
+    sender = models.ForeignKey(User, related_name='group_messaging_sent_messages', on_delete=models.CASCADE)
 
     #comma-separated list of a few names
     senders_info = models.TextField(default='')
@@ -308,12 +311,12 @@ class Message(models.Model):
 
     root = models.ForeignKey(
         'self', null=True,
-        blank=True, related_name='descendants'
+        blank=True, related_name='descendants', on_delete=models.CASCADE
     )
 
     parent = models.ForeignKey(
         'self', null=True,
-        blank=True, related_name='children'
+        blank=True, related_name='children', on_delete=models.CASCADE
     )
 
     headline = models.CharField(max_length=MAX_HEADLINE_LENGTH)
@@ -363,7 +366,7 @@ class Message(models.Model):
                     )
         params = copy.copy(settings['BASE_URL_PARAMS'])
         params['thread_id'] = self.id
-        url = url_getter(user) + '?' + urllib.urlencode(params)
+        url = url_getter(user) + '?' + urllib.parse.urlencode(params)
         #if include_domain_name: #don't need this b/c
         #    site = Site.objects.get_current()
         #    url = 'http://' + site.domain + url
@@ -525,7 +528,7 @@ class UnreadInboxCounter(models.Model):
     user, one has to get all groups user belongs to
     and add up the corresponding counts of unread messages.
     """
-    user = models.ForeignKey(User)
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
     count = models.PositiveIntegerField(default=0)
 
     def decrement(self):
