@@ -1,14 +1,14 @@
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from django.conf import settings as django_settings
 from django.db import transaction
 from askbot import models
 import sys
 
-class Command(NoArgsCommand):
+class Command(BaseCommand):
 
-    def handle_noargs(self, **options):
+    def handle(self, **options):
         user = models.User.objects.get(id=2)
-        for i in xrange(1000):
+        for i in range(1000):
             name = 'tag' + str(i)
             models.Tag.objects.create(
                                 name=name,
