@@ -1,10 +1,10 @@
 import subprocess, os
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 import askbot
 
 DOC_DIR = os.path.join(askbot.get_install_directory(), 'doc')
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, **options):
+class Command(BaseCommand):
+    def handle(self, **options):
         os.chdir(DOC_DIR)
         subprocess.call(['make', 'html'])
