@@ -362,7 +362,9 @@ util.prompt = function(text, defaultInputText, makeLinkMarkdown, dialogType){
             spinner.css('display', 'none');
 
             var startUploadHandler = function(){
-                localUploadFileName = $(this).val();//this is a local var
+                // gets the uploaded file name, fixes the fakepath issue
+                localUploadFileName = $(this).val().replace(/\w:.*\\(.*)$/, '$1');
+
                 /*
                  * startUploadHandler is passed into the ajaxFileUpload
                  * in order to re-install the onchange handler
@@ -859,8 +861,16 @@ util.prompt = function(text, defaultInputText, makeLinkMarkdown, dialogType){
 		var undoMgr; // The undo manager
 
         var isButtonUsed = function(button){
-            var buttons = $.trim(wmd.wmd_env.buttons).split(/\s+/);
-            return $.inArray(button, buttons) !== -1;
+          if (button === 'attachment') {
+            var canUpload = askbot && askbot.data && askbot.data.userCanUploadAttachment;
+            if (!canUpload) return false;
+          }
+          if (button === 'image') {
+            var canUpload = askbot && askbot.data && askbot.data.userCanUploadImage;
+            if (!canUpload) return false;
+          }
+          var buttons = $.trim(wmd.wmd_env.buttons).split(/\s+/);
+          return $.inArray(button, buttons) !== -1;
         };
 
 		// Perform the button's action.
@@ -1829,7 +1839,6 @@ util.prompt = function(text, defaultInputText, makeLinkMarkdown, dialogType){
 			// The function to be executed when you enter a link and press OK or Cancel.
 			// Marks up the link and adds the ref.
     var makeLinkMarkdown = function(link){
-
         if (link !== null) {
 
             chunk.startTag = chunk.endTag = "";
