@@ -3,7 +3,6 @@ import operator
 import logging
 
 from django.contrib.sitemaps import ping_google
-from django.utils import html
 from django.conf import settings as django_settings
 from django.contrib.auth.models import User
 from django.db import models
@@ -26,22 +25,22 @@ from askbot import signals
 from askbot.utils.loading import load_plugin, load_function
 from askbot.utils.slug import slugify
 from askbot import const
-from askbot.models.tag import Tag, MarkedTag
+from askbot.models.tag import MarkedTag
 from askbot.models.tag import tags_match_some_wildcard
 from askbot.models.fields import LanguageCodeField
 from askbot.conf import settings as askbot_settings
 from askbot import exceptions
 from askbot.utils import markup
 from askbot.utils.html import (get_word_count, has_moderated_tags,
-                               moderate_tags, sanitize_html, strip_tags,
+                               moderate_tags, sanitize_html,
                                site_url)
-from askbot.utils.transaction import defer_celery_task
+from askbot.utils.celery_utils import defer_celery_task
 from askbot.models.base import (AnonymousContent, BaseQuerySetManager,
                                 DraftContent)
 
 # TODO: maybe merge askbot.utils.markup and forum.utils.html
 from askbot.utils.diff import textDiff as htmldiff
-from askbot.search import mysql
+#from askbot.search import mysql
 
 
 def default_html_moderator(post):
@@ -99,15 +98,16 @@ class PostQuerySet(models.query.QuerySet):
     # belong to Thread manager or Query set.
     def get_for_user(self, user):
         from askbot.models.user import Group
-        if askbot_settings.GROUPS_ENABLED:
-            if user is None or user.is_anonymous:
-                groups = [Group.objects.get_global_group()]
-            else:
-                groups = user.get_groups()
-            return self.filter(groups__in=groups).distinct()
-        else:
+        if not askbot_settings.GROUPS_ENABLED:
             return self
 
+        if user is None or user.is_anonymous:
+            groups = [Group.objects.get_global_group()]
+        else:
+            groups = user.get_groups()
+
+        return self.filter(groups__in=groups).distinct()
+
     def get_by_text_query(self, search_query):
         """returns a query set of questions,
         matching the full text query
@@ -234,11 +234,6 @@ class PostManager(BaseQuerySetManager):
             post.last_edited_at = added_at
             post.wikified_at = added_at
 
-        # possibly modify the is_private, if one of the groups
-        # mandates explicit publishing of the posts
-        is_private = is_private or \
-            (thread and thread.requires_response_moderation(author))
-
         post.save()  # saved so that revision can have post_id
 
         revision = post.add_revision(
@@ -294,19 +289,15 @@ class PostManager(BaseQuerySetManager):
     def precache_comments(self, for_posts, visitor):
         """
         Fetches comments for given posts, and stores them in post._cached_comments
-        Additionally, annotates posts with ``upvoted_by_user`` parameter, if visitor is logged in
-
+        If visitor is authenticated, annotatets posts with ``upvoted_by_user`` parameter.
+        If visitor is authenticated, adds own comments that are in moderation.
         """
-        qs = Post.objects.get_comments().filter(parent__in=for_posts)\
+        qs = Post.objects.get_comments()\
+            .filter(parent__in=for_posts)\
             .select_related('author')
 
-        comments_reversed = askbot_settings.COMMENTS_REVERSED
-
         if visitor.is_anonymous:
-            if comments_reversed:
-                comments = list(qs.order_by('-added_at'))
-            else:
-                comments = list(qs.order_by('added_at'))
+            comments = list(qs.order_by('added_at'))
         else:
             upvoted_by_user = list(qs.filter(votes__user=visitor).distinct())
             not_upvoted_by_user = list(qs.exclude(votes__user=visitor).distinct())
@@ -315,11 +306,17 @@ class PostManager(BaseQuerySetManager):
                 c.upvoted_by_user = 1  # numeric value to maintain compatibility with previous version of this code
 
             comments = upvoted_by_user + not_upvoted_by_user
-            comments.sort(key=operator.attrgetter('added_at'), reverse=comments_reversed)
+            comments.sort(key=operator.attrgetter('added_at'))
 
+        # filter out comments that user should not see
+        premoderation = askbot_settings.CONTENT_MODERATION_MODE == 'premoderation'
+        if premoderation and visitor.is_authenticated:
+            comments = [comment for comment in comments if (comment.approved or comment.author_id == visitor.pk)]
+            
         post_map = defaultdict(list)
         for cm in comments:
             post_map[cm.parent_id].append(cm)
+
         for post in for_posts:
             post.set_cached_comments(post_map[post.id])
 
@@ -355,6 +352,9 @@ class MockPost(object):
     def needs_moderation(self):
         return False
 
+    def get_post_type_display(self):
+        return self.post_type
+
 
 POST_RENDERERS_MAP = django_settings.ASKBOT_POST_RENDERERS
 def get_post_renderer_type(post_type):
@@ -628,6 +628,16 @@ class Post(models.Model):
 
         return {'diff': diff, 'newly_mentioned_users': newly_mentioned_users}
 
+    def render(self):
+        """Rerenders post html and snippet, no saving."""
+        self.html = self.parse_post_text()['html']
+        self.summary = self.get_snippet()
+
+    def recount_comments(self):
+        """Updates denormalized value `Post.comment_count` according to the
+        number of comments in the database"""
+        self.comment_count = self.comments.filter(deleted=False, approved=True).count()
+
     def is_question(self):
         return self.post_type == 'question'
 
@@ -646,6 +656,33 @@ class Post(models.Model):
     def is_reject_reason(self):
         return self.post_type == 'reject_reason'
 
+    def get_comments_count(self, user):
+        """Returns number of comments under teh post that can be
+        seen by the user"""
+        if not user or user.is_anonymous:
+            return self.comment_count
+
+        return self.comment_count + int(self.has_moderated_comment(user))
+
+    def get_flag_activity_object(self, user):
+        """Returns flag activity object, preferrably initialized by the user,
+        If user is admin or mod, return any flag object.
+        Raises an exception, if object does not exist.
+        """
+        from askbot.models import Activity
+        try:
+            return Activity.objects.get(object_id=self.pk,
+                                        content_type=ContentType.objects.get_for_model(self),
+                                        user_id=user.pk,
+                                        activity_type=const.TYPE_ACTIVITY_MARK_OFFENSIVE)
+        except Activity.DoesNotExist:
+            if not user.is_administrator_or_moderator:
+                raise
+
+            return Activity.objects.get(object_id=self.pk,
+                                        content_type=ContentType.objects.get_for_model(self),
+                                        activity_type=const.TYPE_ACTIVITY_MARK_OFFENSIVE)
+
     def get_last_edited_date(self):
         """returns date of last edit or date of creation
         if there were no edits"""
@@ -654,7 +691,11 @@ class Post(models.Model):
     def get_latest_revision_diff(self, ins_start=None, ins_end=None,
                                  del_start=None, del_end=None):
         # returns formatted html diff of the latest two revisions
-        revisions = self.revisions.order_by('-id')[:2]
+        revisions = self.revisions.exclude(revision=0).order_by('-id')
+        if revisions.count() < 2:
+            return ''
+
+        revisions = revisions[:2]
         return htmldiff(sanitize_html(revisions[1].html),
                         sanitize_html(revisions[0].html),
                         ins_start=ins_start,
@@ -673,6 +714,17 @@ class Post(models.Model):
         #                            )
         return User.objects.filter(user_filter).distinct()
 
+    def get_post_type_display(self):
+        """Returns localized post type"""
+        if self.is_comment():
+            return _('comment')
+        if self.is_answer():
+            return _('answer')
+        if self.is_question():
+            return _('question')
+
+        return _('piece of content')
+
     def get_previous_answer(self, user=None):
         """returns a previous answer to a given answer;
         only works on the "answer" post types"""
@@ -712,15 +764,31 @@ class Post(models.Model):
         """true if post belongs to the group"""
         return self.groups.filter(id=group.id).exists()
 
+    def has_moderated_comment(self, user):
+        """`True` if post has moderated comment authored by user"""
+        if not user:
+            return False
+
+        if user.is_anonymous:
+            return False
+
+        cached_comments = getattr(self, '_cached_comments', None)
+        if cached_comments:
+            for comment in cached_comments:
+                if comment.author_id == user.pk:
+                    if not comment.approved:
+                        return True
+            return False
+
+        return Post.objects.filter(
+            parent=self,
+            post_type='comment',
+            author=user,
+            approved=False
+        ).exists()
+    
     def add_to_groups(self, groups):
         """associates post with groups"""
-        # this is likely to be temporary - we add
-        # vip groups to the list behind the scenes.
-        groups = list(groups)
-        # add moderator groups to the post implicitly
-        from askbot.models.user import Group
-        vips = Group.objects.filter(is_vip=True)
-        groups.extend(vips)
         # TODO: use bulk-creation
         for group in groups:
             PostToGroup.objects.get_or_create(post=self, group=group)
@@ -797,19 +865,20 @@ class Post(models.Model):
                     for_email = [u for u in notify_sets['for_email'] if u.is_administrator()]
                     notify_sets['for_email'] = for_email
 
-        if not django_settings.CELERY_ALWAYS_EAGER:
+        if not getattr(django_settings, 'CELERY_TASK_ALWAYS_EAGER', False):
             cache_key = 'instant-notification-%d-%d' % (self.thread.id, updated_by.id)
             if cache.cache.get(cache_key):
                 return
             cache.cache.set(cache_key, True, django_settings.NOTIFICATION_DELAY_TIME)
 
         from askbot.tasks import send_instant_notifications_about_activity_in_post
+        recipient_ids = [user.id for user in notify_sets['for_email']]
         defer_celery_task(
             send_instant_notifications_about_activity_in_post,
             args=(
                 update_activity.pk,
                 self.id,
-                notify_sets['for_email']
+                recipient_ids
             ),
             countdown=django_settings.NOTIFICATION_DELAY_TIME
         )
@@ -852,11 +921,11 @@ class Post(models.Model):
                 self.remove_from_groups((global_group,))
         else:
             if self.thread_id and self.is_question() is False:
-                # for thread-related responses we base
+                # for thread-related answers and comments we base
                 # privacy scope on thread + add a personal group
-                personal_group = user.get_personal_group()
+                personal_groups = user.get_groups(private=True)
                 thread_groups = self.thread.get_groups_shared_with()
-                groups = set([personal_group]) | set(thread_groups)
+                groups = set(personal_groups) | set(thread_groups)
             else:
                 groups = user.get_groups(private=True)
 
@@ -894,7 +963,7 @@ class Post(models.Model):
         if post.is_question() or post.is_answer():
             comments = Post.objects.get_comments().filter(parent=post)
             comments.update(parent=self)
-            self.comment_count = self.comments.filter(deleted=False).count()
+            self.recount_comments()
 
         # TODO: implement redirects
         if post.is_question():
@@ -958,7 +1027,7 @@ class Post(models.Model):
 
     def needs_moderation(self):
         # TODO: do we need this, can't we just use is_approved()?
-        return self.is_approved() is False
+        return not self.is_approved()
 
     def get_absolute_url(self, no_slug=False, question_post=None,
                          language=None, thread=None):
@@ -1044,8 +1113,6 @@ class Post(models.Model):
             return self.html
 
     def save(self, *args, **kwargs):
-        if self.is_answer() and self.is_anonymous:
-            raise ValueError('Answer cannot be anonymous!')
         super(Post, self).save(*args, **kwargs)
         if self.is_answer() and 'postgres' in askbot.get_database_engine_name():
             # hit the database to trigger update of full text search vector
@@ -1081,15 +1148,12 @@ class Post(models.Model):
         else:
             max_words = int(max_length/5)
 
-        # TODO: truncate so that we have max number of lines
-        # the issue is that code blocks have few words
-        # but very tall, while paragraphs can be dense on words
-        # and fit into fewer lines
-        truncated = Truncator(self.html).words(max_words, truncate=' ...', html=True)
+        from askbot.utils.html import sanitize_html
+        truncated = sanitize_html(Truncator(self.html).words(max_words, truncate=' ...', html=True))
         new_count = get_word_count(truncated)
         orig_count = get_word_count(self.html)
         if new_count + 1 < orig_count:
-            expander = '<span class="expander"> <a>(' + _('more') + ')</a></span>'
+            expander = '<span class="js-expander"> <a>(' + _('more') + ')</a></span>'
             if truncated.endswith('</p>'):
                 # better put expander inside the paragraph
                 snippet = truncated[:-4] + expander + '</p>'
@@ -1097,10 +1161,9 @@ class Post(models.Model):
                 snippet = truncated + expander
             # it is important to have div here, so that we can make
             # the expander work
-            from askbot.utils.html import sanitize_html
-            return sanitize_html('<div class="snippet">' + snippet + '</div>')
-        else:
-            return self.html
+            return '<div class="js-snippet">' + snippet + '</div>'
+
+        return self.html
 
     def filter_authorized_users(self, candidates):
         """returns list of users who are allowed to see this post"""
@@ -1144,11 +1207,16 @@ class Post(models.Model):
             self._cached_comments = list()
             return self._cached_comments
 
-    def add_cached_comment(self, comment):
+    def add_cached_comment(self, comment): #pylint: disable=missing-docstring
         comments = self.get_cached_comments()
         if comment not in comments:
             comments.append(comment)
 
+        def get_timestamp(item): #pylint: disable=missing-docstring
+            return item.added_at
+
+        self.set_cached_comments(sorted(comments, key=get_timestamp))
+
     def reverse_cached_comments(self):
         self.get_cached_comments().reverse()
 
@@ -1170,7 +1238,7 @@ class Post(models.Model):
                                                 ip_addr=ip_addr,
                                             )
         if comment_post.is_approved():
-            self.comment_count = self.comment_count + 1
+            self.recount_comments()
             self.save()
 
         if askbot_settings.COMMENT_EDITING_BUMPS_THREAD:
@@ -1509,23 +1577,32 @@ class Post(models.Model):
     def cache_latest_revision(self, rev):
         setattr(self, '_last_rev_cache', rev)
 
-    def get_latest_revision(self):
+    def get_latest_revision(self, visitor=None):
+        """Returns the latest revision the `visitor` is allowed to see."""
         if hasattr(self, '_last_rev_cache'):
             return self._last_rev_cache
-        rev = self.revisions.order_by('-revision')[0]
+
+        rev = self.revisions.order_by('-id')[0]
+        if not rev.can_be_seen_by(visitor):
+            rev = self.revisions.exclude(revision=0).order_by('-id')[0]
+
         self.cache_latest_revision(rev)
         return rev
-#       # TODO: remove this method
-#       return self.current_revision
 
-    def get_earliest_revision(self):
+    def get_earliest_revision(self, visitor=None):
+        """Returns the earliest revision the `visitor` is allowed to see."""
         if hasattr(self, '_first_rev_cache'):
             return self._first_rev_cache
-        rev = self.revisions.order_by('revision')[0]
+
+        rev = self.revisions.order_by('id')[0]
+        if not rev.can_be_seen_by(visitor):
+            rev = self.revisions.exclude(revision=0).order_by('id')[0]
+
         setattr(self, '_first_rev_cache', rev)
         return rev
 
     def get_latest_revision_number(self):
+        """Returns order number of the latest revision"""
         try:
             return self.get_latest_revision().revision
         except IndexError:
@@ -1813,7 +1890,7 @@ class Post(models.Model):
                     suppress_email=False,
                     ip_addr=None,
                 ):
-        latest_rev = self.get_latest_revision()
+        latest_rev = self.get_latest_revision(edited_by)
 
         if text is None:
             text = latest_rev.text
@@ -1854,7 +1931,7 @@ class Post(models.Model):
                 is_anonymous=edit_anonymously
             )
 
-        if latest_rev.revision > 0:
+        if latest_rev.revision > 0 or not self.approved:
             parse_results = self.parse_and_save(author=edited_by,
                                                 is_private=is_private)
 
@@ -2180,14 +2257,34 @@ class PostRevision(models.Model):
         verbose_name = _("post revision")
         verbose_name_plural = _("post revisions")
 
+    def can_be_seen_by(self, user):
+        """Returns `True` if user can see revision.
+
+        Group membership checks are not done here,
+        because we want this method to not incur additional DB queries.
+
+        Therefore, this method  should not be used directly,
+        but only after the parent posts are filtered by groups.
+        """
+        is_published = self.revision != 0
+
+        if is_published:
+            return True
+        
+        if not user or user.is_anonymous:
+            return False
+
+        # revision is moderated, can be seen by mods or revision authors
+        return user.is_admin_or_mod() or self.author_id == user.pk
+        
+
     def place_on_moderation_queue(self):
         """Creates moderation queue
         Activity items with recipients
         """
         if self.post.revisions.count() == 1:
             if self.revision == 0:
-                # call below hides post from the display to the
-                # general public
+                # call below hides post from the display to the general public
                 self.post.set_is_approved(False)
             activity_type = const.TYPE_ACTIVITY_MODERATED_NEW_POST
         else:
@@ -2247,12 +2344,11 @@ class PostRevision(models.Model):
         schedule = askbot_settings.SELF_NOTIFY_EMAILED_POST_AUTHOR_WHEN
         if schedule == const.NEVER:
             return False
-        elif schedule == const.FOR_FIRST_REVISION:
+        if schedule == const.FOR_FIRST_REVISION:
             return self.revision == 1
-        elif schedule == const.FOR_ANY_REVISION:
+        if schedule == const.FOR_ANY_REVISION:
             return True
-        else:
-            raise ValueError()
+        raise ValueError()
 
     def __str__(self):
         return '%s - revision %s of %s' % (self.post.post_type, self.revision,
@@ -2290,15 +2386,32 @@ class PostRevision(models.Model):
 
         return url
 
+    def get_action_label(self):
+        if self.revision == 0:
+            return _('proposed an edit')
+        if self.revision == 1:
+            if self.post.post_type == 'question':
+                return html_utils.escape(askbot_settings.WORDS_ASKED)
+            if self.post.post_type == 'answer':
+                return html_utils.escape(askbot_settings.WORDS_ANSWERED)
+            return _('posted')
+        return _('updated')
+
     def get_question_title(self):
         # INFO: ack-grepping shows that it's only used for Questions,
         #       so there's no code for Answers
         return self.question.thread.title
 
     def get_origin_post(self):
-        """same as Post.get_origin_post()"""
+        """Same as Post.get_origin_post()"""
         return self.post.get_origin_post()
 
+    def get_original_post_author(self):
+        """Returns original author of the post"""
+        if self.post.post_type in ('question', 'answer'):
+            return self.post.author
+        return None
+
     @property
     def html(self, **kwargs):
         markdowner = markup.get_parser()
