@@ -1,3 +1,4 @@
+import collections
 import datetime
 import logging
 import operator
@@ -8,6 +9,7 @@ from django.conf import settings as django_settings
 from django.db import models
 from django.db.models import F, Q
 from django.contrib.auth.models import User
+from django.contrib.contenttypes.models import ContentType
 from django.core import cache  # import cache, not from cache import cache, to be able to monkey-patch cache.cache in test cases
 from django.core import exceptions as django_exceptions
 from django.template.loader import get_template
@@ -26,7 +28,7 @@ from askbot.models.tag import filter_accepted_tags, filter_suggested_tags
 from askbot.models.tag import separate_unused_tags
 from askbot.models.base import BaseQuerySetManager
 from askbot.models.base import DraftContent, AnonymousContent
-from askbot.models.user import Group, PERSONAL_GROUP_NAME_PREFIX
+from askbot.models.user import Activity, Group, PERSONAL_GROUP_NAME_PREFIX
 from askbot.models.fields import LanguageCodeField
 from askbot import signals
 from askbot import const
@@ -717,10 +719,9 @@ class Thread(models.Model):
         """returns answer count depending on who the user is.
         When user groups are enabled and some answers are hidden,
         the answer count to show must be reflected accordingly"""
-        if not askbot_settings.GROUPS_ENABLED:
-            return self.answer_count
-        else:
+        if askbot_settings.GROUPS_ENABLED:
             return self.get_answers(user).count()
+        return self.answer_count
 
     def get_oldest_answer_id(self, user=None):
         """give oldest visible answer id for the user"""
@@ -734,6 +735,23 @@ class Thread(models.Model):
         answers = self.get_answers(user=user)
         return [answer.id for answer in answers]
 
+    def get_flag_counts_by_post_id(self, user):
+        """Returns a dictionary post_id -> flag_count"""
+        if user.is_anonymous:
+            return {}
+
+        from askbot.models import Post
+        post_ids = Post.objects.filter(thread_id=self.pk).only('pk')
+        flags = Activity.objects.filter(object_id__in=post_ids,
+                                        content_type=ContentType.objects.get_for_model(Post),
+                                        user_id=user.pk,
+                                        activity_type=const.TYPE_ACTIVITY_MARK_OFFENSIVE)
+        flags = flags.only('pk', 'object_id')
+        result = collections.defaultdict(int)
+        for flag in flags:
+            result[flag.object_id] += 1
+        return dict(result)
+
     def get_latest_revision(self, user=None):
         # TODO: add denormalized field to Thread model
         from askbot.models import Post, PostRevision
@@ -835,7 +853,7 @@ class Thread(models.Model):
 
         ####################################################################
         self.invalidate_cached_summary_html()
-        if not django_settings.CELERY_ALWAYS_EAGER:
+        if not getattr(django_settings, 'CELERY_TASK_ALWAYS_EAGER', False):
             self.update_summary_html()  # proactively regenerate thread summary html
         ####################################################################
 
@@ -969,24 +987,7 @@ class Thread(models.Model):
         """true if ``user`` is also a thread moderator"""
         if user.is_anonymous:
             return False
-        if user.is_administrator_or_moderator():
-            if askbot_settings.GROUPS_ENABLED:
-                user_groups = user.get_groups(private=True)
-                thread_groups = self.get_groups_shared_with()
-                return bool(set(user_groups) & set(thread_groups))
-            return True
-        return False
-
-    def requires_response_moderation(self, author):
-        """true, if answers by a given author must be moderated
-        before publishing to the enquirers"""
-        author_groups = author.get_groups()
-        thread_groups = self.get_groups_shared_with()
-        for group in set(author_groups) & set(thread_groups):
-            if group.moderate_answers_to_enquirers:
-                return True
-
-        return False
+        return user.is_administrator_or_moderator()
 
     def tagname_meta_generator(self):
         return ','.join([str(tag) for tag in self.get_tag_names()])
@@ -1032,8 +1033,11 @@ class Thread(models.Model):
         lang = lang or get_language()
         return 'thread-question-summary-%d-%s' % (self.id, lang)
 
-    def get_post_data_cache_key(self, sort_method=None):
-        return 'thread-data-%s-%s' % (self.id, sort_method)
+    def get_post_data_cache_key(self, sort_method=None, groups=None): #pylint: disable=missing-docstring
+        key = f'thread-data-{self.id}-{sort_method}'
+        if not groups:
+            return key
+        return key + '-' + '-'.join(sorted([group.id for group in groups]))
 
     def invalidate_cached_post_data(self):
         """needs to be called when anything notable
@@ -1052,9 +1056,19 @@ class Thread(models.Model):
         self.invalidate_cached_post_data()
         self.invalidate_cached_summary_html()
 
-    def get_post_data_for_question_view(self, user=None, sort_method=None):
-        """loads post data for use in the question details view
-        """
+    def get_public_posts(self):
+        kwargs = {
+            'deleted': False,
+            'post_type__in': ('question', 'answer', 'comment'),
+        }
+        if askbot.is_multilingual():
+            kwargs['language_code'] = self.language_code or get_language()
+        return self.posts.filter(**kwargs)
+
+    def get_personalized_post_data(self, post_data, user):
+        """Returns `post_data` data structure,
+        personalized for user"""
+
         def reverse_comments(post_data):
             question = post_data[0]
             answers = post_data[1]
@@ -1066,7 +1080,7 @@ class Thread(models.Model):
             """posts - is source list
             need_ids - set of post ids
             """
-            found = dict()
+            found = {}
             for post in posts:
                 if post.id in need_ids:
                     found[post.id] = post
@@ -1083,119 +1097,132 @@ class Thread(models.Model):
                 return 1
             return 2
 
-        post_data = self.get_cached_post_data(user=user, sort_method=sort_method)
-        if user.is_anonymous:
-            if askbot_settings.COMMENTS_REVERSED:
-                reverse_comments(post_data)
+        post_data = list(post_data)
+        from askbot.models import PostRevision
+        suggested_revs = PostRevision.objects.filter(author=user, revision=0)
+
+        # users who don't have posts in moderation will incur
+        # quick query and exit
+        if not suggested_revs.count():
             return post_data
 
-        if askbot_settings.CONTENT_MODERATION_MODE == 'premoderation' and user.is_watched():
-            # in this branch we patch post_data with the edits suggested by the
-            # watched user
-            post_data = list(post_data)
-            post_ids = self.posts.filter(author=user).values_list('id', flat=True)
-            from askbot.models import PostRevision
-            suggested_revs = PostRevision.objects.filter(
-                author=user, post__id__in=post_ids, revision=0)
+        # for the remaining users we'll try to patch the thread data
+        # with the users suggested edits
+        question = post_data[0]
+        answers = post_data[1]
+        post_to_author = post_data[2]
 
-            # get ids of posts that we need to patch with suggested data
-            if len(suggested_revs):
-                # find posts that we need to patch
-                suggested_post_ids = [rev.post_id for rev in suggested_revs]
+        all_posts = copy(answers)
+        if question:
+            all_posts.append(question)
 
-                question = post_data[0]
-                answers = post_data[1]
-                post_to_author = post_data[2]
+        post_ids = [post.id for post in all_posts]
 
-                post_id_set = set(suggested_post_ids)
+        suggested_revs = suggested_revs.filter(post_id__in=post_ids)
+        suggested_post_ids = [rev.post_id for rev in suggested_revs]
+        post_id_set = set(suggested_post_ids)
 
-                all_posts = copy(answers)
-                if question:
-                    all_posts.append(question)
-                posts = find_posts(all_posts, post_id_set)
+        # posts that we need to patch with user's suggested edits
+        posts = find_posts(all_posts, post_id_set)
+        rev_map = dict(list(zip(suggested_post_ids, suggested_revs)))
 
-                rev_map = dict(list(zip(suggested_post_ids, suggested_revs)))
+        # patch approved posts with users's revisions pending moderation
+        for post_id, post in list(posts.items()):
+            rev = rev_map[post_id]
+            # patching work
+            post.text = rev.text
+            parse_data = post.parse_post_text()
+            post.html = parse_data['html']
+            post.summary = post.get_snippet()
+            post_to_author[post_id] = rev.author_id
+            post.set_runtime_needs_moderation()
 
-                for post_id, post in list(posts.items()):
-                    rev = rev_map[post_id]
-                    # patching work
-                    post.text = rev.text
-                    parse_data = post.parse_post_text()
-                    post.html = parse_data['html']
-                    post.summary = post.get_snippet()
+        # patch post data with users' posts pending moderation
+        pending_posts = list(self.posts.filter(approved=False, author=user))
+        suggested_revs = PostRevision.objects.filter(post_id__in=[post.id for post in pending_posts])
+        rev_map = {rev.post_id: rev for rev in suggested_revs}
+        for post in sorted(pending_posts, key=post_type_ord):
+            rev = rev_map[post.id]
+            post.text = rev.text
+            post.html = post.parse_post_text()['html']
+            post.summary = post.get_snippet()
+            post_to_author[post.id] = rev.author_id
+            if post.is_comment():
+                parents = find_posts(all_posts, set([post.parent_id]))
+                parent = list(parents.values())[0]
+                parent.add_cached_comment(post)
+            if post.is_answer():
+                answers.insert(0, post)
+                all_posts.append(post)# add b/c there may be self-comments
+            if post.is_question():
+                post_data[0] = post
+                all_posts.append(post)
 
-                    post_to_author[post_id] = rev.author_id
-                    post.set_runtime_needs_moderation()
-
-                if len(post_id_set):
-                    # brand new suggested posts
-                    from askbot.models import Post
-                    # order by insures that
-                    posts = list(Post.objects.filter(id__in=post_id_set))
-                    for post in sorted(posts, key=post_type_ord):
-                        rev = rev_map[post.id]
-                        post.text = rev.text
-                        post.html = post.parse_post_text()['html']
-                        post.summary = post.get_snippet()
-                        post_to_author[post.id] = rev.author_id
-                        if post.is_comment():
-                            parents = find_posts(all_posts, set([post.parent_id]))
-                            parent = list(parents.values())[0]
-                            parent.add_cached_comment(post)
-                        if post.is_answer():
-                            answers.insert(0, post)
-                            all_posts.append(post)# add b/c there may be self-comments
-                        if post.is_question():
-                            post_data[0] = post
-                            all_posts.append(post)
-
-        if askbot_settings.COMMENTS_REVERSED:
-            reverse_comments(post_data)
         return post_data
 
+    def get_post_data_for_question_view(self, user=None, sort_method=None):
+        """loads post data for use in the question details view
+        """
+        post_data = self.get_cached_post_data(user=user, sort_method=sort_method)
+        if user.is_anonymous:
+            return post_data
+
+        if not (askbot_settings.CONTENT_MODERATION_MODE == 'premoderation' and user.is_watched()):
+            return post_data
+
+        return self.get_personalized_post_data(post_data, user)
+
+    def get_groups_for_get_post_data(self, user):
+        """Returns groups necessary for `Thread.get_post_data`"""
+        if not askbot_settings.GROUPS_ENABLED:
+            return []
+
+        if not user or user.is_anonymous:
+            return [Group.objects.get_global_group(),]
+
+        all_groups = set(user.get_groups())
+        personal = set([user.get_personal_group()])
+        return list(all_groups - personal)
+
+
     def get_cached_post_data(self, user=None, sort_method=None):
         """returns cached post data, as calculated by
         the method get_post_data()"""
         sort_method = sort_method or askbot_settings.DEFAULT_ANSWER_SORT_METHOD
+        groups = self.get_groups_for_get_post_data(user)
+        if groups:
+            # A temporary hacky plug. 
+            # We could cache by groups as well, but in that case invalidation
+            # becomes an issue.
+            return self.get_post_data(sort_method=sort_method, groups=groups)
 
-        if askbot_settings.GROUPS_ENABLED:
-            # temporary plug: bypass cache where groups are enabled
-            return self.get_post_data(sort_method=sort_method, user=user)
-        key = self.get_post_data_cache_key(sort_method)
+        key = self.get_post_data_cache_key(sort_method, groups)
         post_data = cache.cache.get(key)
         if not post_data:
-            post_data = self.get_post_data(sort_method)
+            post_data = self.get_post_data(sort_method=sort_method, groups=groups)
             cache.cache.set(key, post_data, const.LONG_TIME)
         return post_data
 
-    def get_public_posts(self):
-        kwargs = {
-            'deleted': False,
-            'post_type__in': ('question', 'answer', 'comment'),
-        }
-        if askbot.is_multilingual():
-            kwargs['language_code'] = self.language_code or get_language()
-        return self.posts.filter(**kwargs)
+    def get_post_data(self, sort_method=None, groups=None):
+        """
+        returns a tuple of four values:
+        * question
+        * answers as list
+        * list of post ids 
+        * list of published post ids
 
-    def get_post_data(self, sort_method=None, user=None):
-        """returns question, answers as list and a list of post ids
-        for the given thread, and the list of published post ids
-        (four values)
         the returned posts are pre-stuffed with the comments
-        all (both posts and the comments sorted in the correct
-        order)
+        the posts and the comments sorted in the correct order
         """
         sort_method = sort_method or askbot_settings.DEFAULT_ANSWER_SORT_METHOD
 
-        thread_posts = self.posts.all()
-        if askbot_settings.GROUPS_ENABLED:
-            if user is None or user.is_anonymous:
-                groups = (Group.objects.get_global_group(),)
-            else:
-                groups = user.get_groups()
-
-            thread_posts = thread_posts.filter(groups__in=groups)
-            thread_posts = thread_posts.distinct()# important for >1 group
+        if groups:
+            posts = self.posts.filter(groups__in=groups, approved=True)
+            if len(groups) > 1:
+                # important for >1 group
+                posts = posts.distinct()
+        else:
+            posts = self.posts.filter(approved=True)
 
         order_by_method = {
                         'latest':'-added_at',
@@ -1213,14 +1240,19 @@ class Thread(models.Model):
         else:
             order_by = (order_by,)
 
-        thread_posts = thread_posts.order_by(*order_by)
+        posts = posts.order_by(*order_by)
         # 1) collect question, answer and comment posts and list of post id's
         answers = list()
         post_map = dict()
         comment_map = dict()
         post_to_author = dict()
         question_post = None
-        for post in thread_posts:
+
+        for post in posts:
+
+            if post.post_type not in ('question', 'answer', 'comment'):
+                continue
+
             # precache some revision data
             first_rev = post.get_earliest_revision()
             last_rev = post.get_latest_revision()
@@ -1230,7 +1262,8 @@ class Thread(models.Model):
             # pass through only deleted question posts
             if post.deleted and post.post_type != 'question':
                 continue
-            if not post.is_approved():  # hide posts on the moderation queue
+
+            if not post.is_approved():
                 continue
 
             post_to_author[post.id] = post.author_id
@@ -1238,11 +1271,13 @@ class Thread(models.Model):
             if post.post_type == 'answer':
                 answers.append(post)
                 post_map[post.id] = post
-            elif post.post_type == 'comment':
+
+            if post.post_type == 'comment':
                 if post.parent_id not in comment_map:
                     comment_map[post.parent_id] = list()
                 comment_map[post.parent_id].append(post)
-            elif post.post_type == 'question':
+
+            if post.post_type == 'question':
                 assert(question_post is None)
                 post_map[post.id] = post
                 question_post = post
@@ -1267,31 +1302,26 @@ class Thread(models.Model):
                     answers.remove(accepted_answer)
                     answers.insert(0, accepted_answer)
 
-        # if user is not an inquirer, and thread is moderated,
-        # put published answers first
-        # TODO: there may be > 1 enquirers
-        published_answer_ids = list()
-        if question_post and not question_post.is_approved() and user != question_post.author:
-            # if moderated - then author is guaranteed to be the
-            # limited visibility enquirer
-            # TODO: may be > 1 user
-            published_answer_ids = self.posts\
-                .get_answers(user=question_post.author)\
-                .filter(deleted=False)\
-                .order_by(*order_by)\
-                .values_list('id', flat=True)
+        # when there was the "private forum" feature,
+        # this block below was under an if branch - if the
+        # if question_post and not question_post.is_approved() and user != question_post.author:
+        published_answer_ids = self.posts\
+            .get_answers()\
+            .filter(deleted=False)\
+            .order_by(*order_by)\
+            .values_list('id', flat=True)
 
-            published_answer_ids = reversed(published_answer_ids)
-            # now put those answers first
-            answer_map = dict([(answer.id, answer) for answer in answers])
-            for answer_id in published_answer_ids:
-                # note that answer map may not contain answers publised
-                # to the question enquirer, because current user may
-                # not have access to that answer, so we use the .get() method
-                answer = answer_map.get(answer_id, None)
-                if answer:
-                    answers.remove(answer)
-                    answers.insert(0, answer)
+        published_answer_ids = list(reversed(published_answer_ids))
+        # now put those answers first
+        answer_map = dict([(answer.id, answer) for answer in answers])
+        for answer_id in published_answer_ids:
+            # note that answer map may not contain answers publised
+            # to the question enquirer, because current user may
+            # not have access to that answer, so we use the .get() method
+            answer = answer_map.get(answer_id, None)
+            if answer:
+                answers.remove(answer)
+                answers.insert(0, answer)
 
         return (question_post, answers, post_to_author, published_answer_ids)
 
@@ -1396,12 +1426,7 @@ class Thread(models.Model):
     def is_moderated(self):
         """True, if tread has SHOW_PUBLISHED_RESPONSES
         group memberships"""
-        if askbot_settings.GROUPS_ENABLED:
-            return ThreadToGroup.objects.filter(
-                            thread=self,
-                            visibility=ThreadToGroup.SHOW_PUBLISHED_RESPONSES
-                        ).count() > 0
-        return False
+        return askbot_settings.GROUPS_ENABLED
 
     def add_child_posts_to_groups(self, groups):
         """adds questions and answers of the thread to
@@ -1721,7 +1746,7 @@ class Thread(models.Model):
         }
         from askbot.views.context import get_extra as get_extra_context
         context.update(get_extra_context('ASKBOT_QUESTION_SUMMARY_EXTRA_CONTEXT', None, context))
-        template = get_template('widgets/question_summary.html')
+        template = get_template('questions/question_summary.html')
         html = template.render(Context(context))
         # INFO: Timeout is set to 30 days:
         # * timeout=0/None is not a reliable cross-backend way to set infinite timeout
