@@ -4,7 +4,7 @@ with the reputation system, but should be separated."""
 from django.db import models
 from django.contrib.auth.models import User
 
-#todo: migrate here all permissions defined
+#TODO: migrate here all permissions defined
 #by user's status, reputation,
 #methods User.assert_can... , etc.
 #after that retire field User.status, except
@@ -24,10 +24,9 @@ def get_role_set(status):
     """Returns role set corresponding to the user status"""
     if status == 'administrator':
         return ADMIN_ROLES
-    elif status == 'moderator':
+    if status == 'moderator':
         return MOD_ROLES
-    else:
-        raise ValueError('unsupported status {}'.format(status))
+    raise ValueError(f'unsupported status {status}')
 
 
 class Role(models.Model):
@@ -35,7 +34,7 @@ class Role(models.Model):
     user = models.ForeignKey(User, related_name='askbot_roles', on_delete=models.CASCADE)
     role = models.CharField(max_length=64, choices=ROLE_CHOICES)
 
-    class Meta: #pylint: disable=missing-docstring, old-style-class, no-init, too-few-public-methods
+    class Meta: #pylint: disable=missing-docstring, no-init, too-few-public-methods
         app_label = 'askbot'
         db_table = 'askbot_role'
         unique_together = ('user', 'role')
