@@ -592,12 +592,12 @@ class Group(AuthGroup):
                     null=True, blank=True, on_delete=models.CASCADE
                 )
     moderate_email = models.BooleanField(default=True)
-    moderate_answers_to_enquirers = models.BooleanField(
-                        default=False,
-                        help_text=_('If true, answers to outsiders questions '
-                                    'will be shown to the enquirers only when '
-                                    'selected by the group moderators.')
-                    )
+    can_post_questions = models.BooleanField(default=False)
+    can_post_answers = models.BooleanField(default=False)
+    can_post_comments = models.BooleanField(default=False)
+    can_upload_attachments = models.BooleanField(default=False)
+    can_upload_images = models.BooleanField(default=False)
+
     openness = models.SmallIntegerField(default=CLOSED, choices=OPENNESS_CHOICES)
     # preapproved email addresses and domain names to auto-join groups
     # trick - the field is padded with space and all tokens are space separated
@@ -607,9 +607,6 @@ class Group(AuthGroup):
     preapproved_email_domains = models.TextField(
         null=True, blank=True, default='')
 
-    is_vip = models.BooleanField(
-        default=False,
-        help_text=_('Check to make members of this group site moderators'))
     read_only = models.BooleanField(default=False)
 
     objects = GroupManager()
