@@ -147,84 +147,6 @@ class TagNamesFieldTests(AskbotTestCase):
         self.assert_tags_equal(cleaned_tags, ['oneness'])
 
 
-class EditQuestionAnonymouslyFormTests(AskbotTestCase):
-    """setup the following truth table
-    on reveal_identity field:
-    is_anon  can  owner  checked  result
-
-    """
-    truth_table = (
-        (0, 0, 0, 0, False),
-        (0, 0, 0, 1, False),
-        (0, 0, 1, 0, False),
-        (0, 0, 1, 1, False),
-        (0, 1, 0, 0, False),
-        (0, 1, 0, 1, False),
-        (0, 1, 1, 0, False),
-        (0, 1, 1, 1, False),  # all up to this point are False
-        (1, 0, 0, 0, False),
-        (1, 1, 0, 0, False),
-        (1, 1, 1, 0, False),
-        (1, 1, 1, 1, True),
-    )
-
-    # legend: is_anon - question is anonymous
-    #         can - askbot_settings.ALLOW_ASK_ANONYMOUSLY
-    #         owner - editor is question owner
-    #         checked - the checkbox "reveal_identity" is marked
-    def setUp(self):
-        self.create_user()
-        self.create_user(
-            username='other_user',
-            status='m'  # must be able to edit
-        )
-        super(EditQuestionAnonymouslyFormTests, self).setUp()
-
-    def setup_data(self, is_anon, can_be_anon, is_owner, box_checked):
-        """sets up data in the same order as shown in the
-        truth table above
-
-        the four positional arguments are in the same order
-        """
-        askbot_settings.update('ALLOW_ASK_ANONYMOUSLY', can_be_anon)
-        question = self.post_question(is_anonymous=is_anon)
-        if is_owner:
-            editor = self.user
-        else:
-            editor = self.other_user
-        data = {
-            'tags': 'tag1 tag2',
-            'text': 'ostaousohuosuh',
-            'title': 'stahosetuhaoeudhuh'
-        }
-        if box_checked:
-            data['reveal_identity'] = 'on'
-        self.form = forms.EditQuestionForm(
-                        data,
-                        question=question,
-                        user=editor,
-                        revision=question.get_latest_revision(),
-                    )
-
-    def test_reveal_identity_field(self):
-        """runs through the truth table and tests them items by one
-        """
-        current_item = 0
-        for entry in self.truth_table:
-            self.setup_data(*(entry[:4]))
-
-            if self.form.is_valid():
-                result = self.form.cleaned_data.get('reveal_identity', False)
-            else:
-                result = 'error'
-
-            error_message = 'failed truth table item %d' % current_item
-            current_item += 1
-
-            expected_result = entry[4]
-            self.assertEqual(result, expected_result, error_message)
-
-
 class AskFormTests(AskbotTestCase):
     def setup_data(self, allow_anonymous=True, ask_anonymously=None):
         askbot_settings.update('ALLOW_ASK_ANONYMOUSLY', allow_anonymous)
