@@ -1,3 +1,4 @@
+from unittest import skip
 from askbot.tests.utils import AskbotTestCase
 from askbot.conf import settings as askbot_settings
 from askbot import models
@@ -9,6 +10,11 @@ class ThreadModelTestsWithGroupsEnabled(AskbotTestCase):
     def setUp(self):
         self.groups_enabled_backup = askbot_settings.GROUPS_ENABLED
         askbot_settings.update('GROUPS_ENABLED', True)
+        global_group = models.Group.objects.get_global_group()
+        global_group.can_post_questions = True
+        global_group.can_post_answers = True
+        global_group.can_post_comments = True
+        global_group.save()
         self.admin = self.create_user('admin', status = 'd')
         self.user = self.create_user(
             'user',
@@ -20,12 +26,15 @@ class ThreadModelTestsWithGroupsEnabled(AskbotTestCase):
                 'm_and_c': 'i'
             }
         )
+        self.user.new_response_count = 0
+        self.user.seen_response_count = 0
+        self.user.save()
         self.group = models.Group.objects.get_or_create(name='jockeys')
-        self.admin.edit_group_membership(
-            group = self.group,
-            user = self.admin,
-            action = 'add'
-        )
+        self.group.can_post_questions = True
+        self.group.can_post_answers = True
+        self.group.can_post_comments = True
+        self.group.save()
+        self.admin.join_group(self.group)
 
     def tearDown(self):
         askbot_settings.update('GROUPS_ENABLED', self.groups_enabled_backup)
@@ -34,11 +43,9 @@ class ThreadModelTestsWithGroupsEnabled(AskbotTestCase):
         # post question, answer, add answer to the group
         self.question = self.post_question(self.user)
 
-        self.answer = self.post_answer(
-            user = self.admin,
-            question = self.question,
-            is_private = True
-        )
+        self.answer = self.post_answer(user=self.admin,
+                                       question=self.question,
+                                       is_private=True)
 
         thread = self.question.thread
 
@@ -49,12 +56,10 @@ class ThreadModelTestsWithGroupsEnabled(AskbotTestCase):
         #test mail outbox
         self.assertEqual(len(django.core.mail.outbox), 0)
         user = self.reload_object(self.user)
+        # error below
         self.assertEqual(user.new_response_count, 0)
 
-        self.admin.edit_answer(
-            self.answer,
-            is_private = False
-        )
+        self.admin.edit_answer(self.answer, is_private=False)
         self.assertEqual(len(django.core.mail.outbox), 1)
         user = self.reload_object(self.user)
         self.assertEqual(user.new_response_count, 1)
@@ -80,45 +85,7 @@ class ThreadModelTestsWithGroupsEnabled(AskbotTestCase):
         )
 
 
-    def test_restrictive_response_publishing(self):
-        #restrictive model should work even with groups
-        #in common between the asker and the answerer
-        common_group = models.Group(
-                        name='common',
-                        openness=models.Group.OPEN
-                    )
-        common_group.save()
-        self.admin.join_group(common_group)
-        self.user.join_group(common_group)
-
-        self.group.moderate_answers_to_enquirers = True
-        self.group.save()
-        question = self.post_question(user=self.user, group_id=self.group.id)
-        answer = self.post_answer(question=question, user=self.admin)
-
-        #answer and the user don't have groups in common
-        answer_groups = set(answer.groups.all())
-        user_groups = set(self.user.get_groups())
-        self.assertEqual(len(answer_groups & user_groups), 0)
-
-        #publish the answer
-        self.client.login(user_id=self.admin.id, method='force')
-        self.client.post(
-            reverse('publish_answer'),
-            data={'answer_id': answer.id},
-            HTTP_X_REQUESTED_WITH='XMLHttpRequest'
-        )
-        #todo: test redirect
-
-        answer = self.reload_object(answer)
-        answer_groups = set(answer.groups.all())
-        self.assertEqual(len(answer_groups & user_groups), 1)
-
-
-
     def test_permissive_response_publishing(self):
-        self.group.moderate_answers_to_enquirers = False
-        self.group.save()
         question = self.post_question(user=self.user, group_id=self.group.id)
         answer = self.post_answer(question=question, user=self.admin)
 
