@@ -26,7 +26,7 @@ example of desired structure, when input is parsed
     ]
 """
 from askbot.conf import settings as askbot_settings
-import simplejson
+import json
 
 def get_leaf_index(tree, leaf_name):
     children = tree[1]
@@ -52,7 +52,7 @@ def get_subtree(tree, path):
 
 def sort_tree(tree):
     """sorts contents of the nodes alphabetically"""
-    tree = sorted(tree, lambda x,y: cmp(x[0], y[0]))
+    tree = sorted(tree, key=lambda x: x[0])
     for item in tree:
         item[1] = sort_tree(item[1])
     return tree
@@ -62,7 +62,7 @@ def get_data():
     or None, if category_tree is disabled
     """
     if askbot_settings.TAG_SOURCE == 'category-tree':
-        return simplejson.loads(askbot_settings.CATEGORY_TREE)
+        return json.loads(askbot_settings.CATEGORY_TREE)
     else:
         return None
 
@@ -93,7 +93,7 @@ def add_category(tree, category_name, path):
     subtree = get_subtree(tree, path)
     children = subtree[1]
     children.append([category_name, []])
-    children = sorted(children, lambda x,y: cmp(x[0], y[0]))
+    children = sorted(children, key=lambda x: x[0])
     subtree[1] = children
     new_path = path[:]
     #todo: reformulate all paths in terms of names?
@@ -145,5 +145,5 @@ def delete_category(tree, name, path):
 
 def save_data(tree):
     assert(askbot_settings.TAG_SOURCE == 'category-tree')
-    tree_json = simplejson.dumps(tree)
+    tree_json = json.dumps(tree)
     askbot_settings.update('CATEGORY_TREE', tree_json)
