@@ -6,6 +6,7 @@ By main textual content is meant - text of Questions, Answers and Comments.
 The "read-only" requirement here is not 100% strict, as for example "question" view does
 allow adding new comments via Ajax form post.
 """
+import html
 import logging
 import urllib.request, urllib.parse, urllib.error
 import operator
@@ -15,6 +16,7 @@ from django.http import HttpResponseRedirect
 from django.http import HttpResponse
 from django.http import Http404
 from django.http import HttpResponseNotAllowed
+from django.http import HttpResponseForbidden
 from django.http import HttpResponseBadRequest
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.template.loader import get_template
@@ -39,8 +41,10 @@ from askbot.forms import GetDataForPostForm
 from askbot.forms import GetUserItemsForm
 from askbot.forms import ShowTagsForm
 from askbot.forms import ShowQuestionForm
+from askbot.forms import SearchPostsForm
 from askbot.models.post import MockPost
 from askbot.models.tag import Tag
+from askbot.models.recent_contributors import AvatarsBlockData
 from askbot.search.state_manager import SearchState, DummySearchState
 from askbot.startup_procedures import domain_is_bad
 from askbot.templatetags import extra_tags
@@ -74,9 +78,8 @@ def questions(request, **kwargs):
     List of Questions, Tagged questions, and Unanswered questions.
     matching search query or user selection
     """
-    #before = timezone.now()
-    if request.method != 'GET':
-        return HttpResponseNotAllowed(['GET'])
+    if request.method not in ('GET', 'HEAD'):
+        return HttpResponseNotAllowed(['GET', 'HEAD'])
 
     search_state = SearchState(
                     user_logged_in=request.user.is_authenticated,
@@ -86,6 +89,7 @@ def questions(request, **kwargs):
     qs, meta_data = models.Thread.objects.run_advanced_search(
                         request_user=request.user, search_state=search_state
                     )
+
     if meta_data['non_existing_tags']:
         search_state = search_state.remove_tags(meta_data['non_existing_tags'])
 
@@ -107,14 +111,7 @@ def questions(request, **kwargs):
     if tag_list_type == 'cloud': #force cloud to sort by name
         related_tags = sorted(related_tags, key = operator.attrgetter('name'))
 
-    contributors = list(
-        models.Thread.objects.get_thread_contributors(
-                                        thread_list=page.object_list
-                                    ).only(
-                                           'id', 'username',
-                                           'askbot_profile__gravatar'
-                                          )
-                        )
+    contributors = AvatarsBlockData.get_data()
 
     paginator_context = {
         'is_paginated' : (paginator.count > search_state.page_size),
@@ -149,12 +146,8 @@ def questions(request, **kwargs):
     if request.is_ajax():
         q_count = paginator.count
 
-        #todo: words
-        question_counter = ungettext('%(q_num)s question', '%(q_num)s questions', q_count)
-        question_counter = question_counter % {'q_num': humanize.intcomma(q_count),}
-
         if q_count > search_state.page_size:
-            paginator_tpl = get_template('main_page/paginator.html')
+            paginator_tpl = get_template('questions/paginator.html')
             paginator_html = paginator_tpl.render(
                     {
                         'context': paginator_context,
@@ -167,16 +160,15 @@ def questions(request, **kwargs):
         else:
             paginator_html = ''
 
-        questions_tpl = get_template('main_page/questions_loop.html')
-        questions_html = questions_tpl.render(
-                {
-                    'threads': page,
-                    'search_state': search_state,
-                    'reset_method_count': reset_method_count,
-                    'request': request
-                },
-                request
-        )
+        questions_tpl = get_template('questions/questions.html')
+        questions_html = questions_tpl.render({'threads': page,
+                                               'search_state': search_state,
+                                               'reset_method_count': reset_method_count,
+                                               'request': request},
+                                              request)
+
+        question_list_title_tpl = get_template('questions/questions_title.html')
+        question_list_title = question_list_title_tpl.render({'questions_count': q_count})
 
         ajax_data = {
             'query_data': {
@@ -185,7 +177,7 @@ def questions(request, **kwargs):
                 'ask_query_string': search_state.ask_query_string(),
             },
             'paginator': paginator_html,
-            'question_counter': question_counter,
+            'question_list_title': question_list_title,
             'faces': [],#[extra_tags.gravatar(contributor, 48) for contributor in contributors],
             'feed_url': context_feed_url,
             'query_string': search_state.query_string(),
@@ -239,7 +231,6 @@ def questions(request, **kwargs):
             'subscribed_tag_names': meta_data.get('subscribed_tag_names', None),
             'language_code': translation.get_language(),
             'name_of_anonymous_user' : models.get_name_of_anonymous_user(),
-            'page_class': 'main-page',
             'page_size': search_state.page_size,
             'query': search_state.query,
             'threads' : page,
@@ -252,7 +243,6 @@ def questions(request, **kwargs):
             'tab_id' : search_state.sort,
             'tags' : related_tags,
             'tag_list_type' : tag_list_type,
-            'font_size' : extra_tags.get_tag_font_size(related_tags),
             'display_tag_filter_strategy_choices': conf.get_tag_display_filter_strategy_choices(),
             'email_tag_filter_strategy_choices': conf.get_tag_email_filter_strategy_choices(),
             'query_string': search_state.query_string(),
@@ -260,6 +250,9 @@ def questions(request, **kwargs):
             'feed_url': context_feed_url
         }
 
+        if tag_list_type == 'cloud':
+            template_data['font_size'] = extra_tags.get_tag_font_size(related_tags)
+
         extra_context = context.get_extra(
                                     'ASKBOT_QUESTIONS_PAGE_EXTRA_CONTEXT',
                                     request,
@@ -281,9 +274,10 @@ def questions(request, **kwargs):
                 ) % url
                 request.user.message_set.create(message=msg)
 
-        return render(request, 'main_page.html', template_data)
-        #print timezone.now() - before
-        #return res
+        #before = timezone.now()
+        result = render(request, 'questions/index.html', template_data)
+        #print('pure render time %s' % (timezone.now() - before))
+        return result
 
 
 def get_top_answers(request):
@@ -334,7 +328,6 @@ def tags(request):#view showing a listing of available tags - plain list
     #3) Start populating the template context.
     data = {
         'active_tab': 'tags',
-        'page_class': 'tags-page',
         'tag_list_type' : tag_list_type,
         'query' : query,
         'tab_id' : sort_method,
@@ -374,7 +367,69 @@ def tags(request):#view showing a listing of available tags - plain list
         json_string = json.dumps(json_data)
         return HttpResponse(json_string, content_type='application/json')
     else:
-        return render(request, 'tags.html', data)
+        return render(request, 'tags/index.html', data)
+
+
+def should_show_answer_form(user, thread, answers):
+    """A utility function, used in the question detail view.
+    Thread and answers are given as separate arguments
+    with a purpose of performance optimization (i.e. we cannot do thread.get_answers(), etc.)
+    """
+    if thread.closed:
+        return False
+
+    if askbot_settings.READ_ONLY_MODE_ENABLED:
+        return False
+
+    if not user.is_authenticated:
+        # we don't know if user has previous answers
+        if askbot_settings.LIMIT_ONE_ANSWER_PER_USER:
+            return False
+
+    if askbot_settings.GROUPS_ENABLED:
+        if user.is_authenticated:
+            if not user.can_post_answer(thread):
+                return False
+
+        if askbot_settings.ALLOW_POSTING_BEFORE_LOGGING_IN:
+            if models.Group.objects.get_global_group().can_post_answers:
+                return True
+
+    if user.is_authenticated and askbot_settings.LIMIT_ONE_ANSWER_PER_USER:
+        for answer in answers:
+            if answer.author_id == user.pk:
+                return False
+
+    if user.is_authenticated:
+        return True
+
+    if askbot_settings.ALLOW_POSTING_BEFORE_LOGGING_IN:
+        return True
+
+    return False
+
+
+def should_hide_answer_ui(user, thread):
+    """Hide answer form and any buttons related
+    to answers - only when we are not sure if
+    the user will be able to post an answer.
+    This applies only when there are groups
+    that are not allowed to post answers.
+    """
+    if thread.closed:
+        return True
+
+    if askbot_settings.READ_ONLY_MODE_ENABLED:
+        return True
+
+    if not askbot_settings.GROUPS_ENABLED:
+        return False
+
+    if user.is_anonymous:
+        return True
+
+    return not user.has_group_permission('post_answers')
+
 
 @csrf.csrf_protect
 def question(request, id):#refactor - long subroutine. display question body, answers and comments
@@ -602,22 +657,18 @@ def question(request, id):#refactor - long subroutine. display question body, an
     else:
         answer_form_class = AnswerForm
 
-    answer_form = answer_form_class(initial=initial, user=request.user)
+    answer_form = answer_form_class(initial=initial, user=request.user, label_suffix='')
 
     user_can_post_comment = (
         request.user.is_authenticated \
         and request.user.can_post_comment(question_post)
     )
 
-    new_answer_allowed = True
     previous_answer = None
-    if request.user.is_authenticated:
-        if askbot_settings.LIMIT_ONE_ANSWER_PER_USER:
-            for answer in answers:
-                if answer.author_id == request.user.pk:
-                    new_answer_allowed = False
-                    previous_answer = answer
-                    break
+    if request.user.is_authenticated and askbot_settings.LIMIT_ONE_ANSWER_PER_USER:
+        for answer in answers:
+            if answer.author_id == request.user.pk:
+                previous_answer = answer
 
     if request.user.is_authenticated and askbot_settings.GROUPS_ENABLED:
         group_read_only = request.user.is_read_only()
@@ -641,9 +692,9 @@ def question(request, id):#refactor - long subroutine. display question body, an
         'is_cacheable': False,#is_cacheable, #temporary, until invalidation fix
         'language_code': translation.get_language(),
         'long_time': const.LONG_TIME,#"forever" caching
-        'new_answer_allowed': new_answer_allowed,
+        'show_answer_form': should_show_answer_form(request.user, thread, answers),
+        'hide_answer_ui': should_hide_answer_ui(request.user, thread),
         'oldest_answer_id': thread.get_oldest_answer_id(request.user),
-        'page_class': 'question-page',
         'paginator_context' : paginator_context,
         'previous_answer': previous_answer,
         'published_answer_ids': published_answer_ids,
@@ -654,11 +705,12 @@ def question(request, id):#refactor - long subroutine. display question body, an
         'similar_threads' : thread.get_similar_threads(),
         'tab_id' : answer_sort_method,
         'thread': thread,
-        'thread_is_moderated': thread.is_moderated(),
         'user_is_thread_moderator': thread.has_moderator(request.user),
         'user_votes': user_votes,
         'user_post_id_list': user_post_id_list,
+        'user_flag_counts_by_post_id': thread.get_flag_counts_by_post_id(request.user),
         'user_can_post_comment': user_can_post_comment,#in general
+        'question_detail_page': True
     }
     #shared with ...
     if askbot_settings.GROUPS_ENABLED:
@@ -669,7 +721,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
     extra = context.get_extra('ASKBOT_QUESTION_PAGE_EXTRA_CONTEXT', request, data)
     data.update(extra)
 
-    return render(request, 'question.html', data)
+    return render(request, 'question/index.html', data)
     #print 'generated in ', timezone.now() - before
     #return res
 
@@ -683,7 +735,6 @@ def revisions(request, id, post_type = None):
             raise Http404
 
     revisions = list(models.PostRevision.objects.filter(post=post))
-    revisions.reverse()
     for i, revision in enumerate(revisions):
         if i == 0:
             revision.diff = sanitize_html(revisions[i].html)
@@ -694,12 +745,9 @@ def revisions(request, id, post_type = None):
                 sanitize_html(revision.html)
             )
 
-    data = {
-        'page_class':'revisions-page',
-        'active_tab':'questions',
-        'post': post,
-        'revisions': revisions,
-    }
+    data = {'active_tab':'questions',
+            'post': post,
+            'revisions': revisions}
     return render(request, 'revisions.html', data)
 
 @ajax_only
@@ -710,15 +758,10 @@ def get_comment(request):
     via ajax response requires request method get
     and request must be ajax
     """
-    id = int(request.GET['id'])
-    comment = models.Post.objects.get(post_type='comment', id=id)
+    post_id = int(request.GET['id'])
+    comment = models.Post.objects.get(post_type='comment', id=post_id)
     request.user.assert_can_edit_comment(comment)
-
-    try:
-        #try to get suggested edit
-        rev = comment.revisions.get(revision=0)
-    except models.PostRevision.DoesNotExist:
-        rev = comment.get_latest_revision()
+    rev = comment.get_latest_revision(request.user)
     return {'text': rev.text}
 
 
@@ -786,3 +829,77 @@ def get_post_html(request):
     post = models.Post.objects.get(id=request.GET['post_id'])
     post.assert_is_visible_to(request.user)
     return {'post_html': post.html}
+
+
+def search_posts(request):
+    """Allows searching for posts by text and post id,
+    browsing matching posts forwards and backwards by ID.
+    """
+    if not request.user.is_authenticated:
+        return HttpResponseForbidden()
+
+    if not request.user.is_admin_or_mod():
+        return HttpResponseForbidden()
+
+    if request.method == 'POST':
+        request_data = request.POST
+    else:
+        request_data = request.GET
+
+    form = SearchPostsForm(request_data)
+    form.full_clean()
+
+    query_string = form.cleaned_data.get('q', '')
+    post_id = form.cleaned_data.get('post_id', None)
+    post_ord = form.cleaned_data.get('post_ord', None)
+
+    post_types = ('question', 'answer', 'comment')
+    posts = Post.objects.filter(post_type__in=post_types).order_by('id')
+
+    if query_string:
+        posts = posts.filter(text__icontains=query_string)
+
+    posts_count = posts.count()
+
+    post = None
+    if post_id:
+        try:
+            post = posts.get(pk=post_id)
+        except Post.DoesNotExist:
+            pass
+    elif post_ord:
+        try:
+            post = posts[post_ord - 1]
+        except IndexError:
+            pass
+    elif posts_count:
+        post = posts[0]
+
+    if post and not post_ord:
+        post_ord = posts.filter(id__lt=post.pk).count() + 1
+
+    prev_post, next_post = [None] * 2
+    if post:
+        prev_posts = posts.filter(pk__lt=post.pk).only('id').order_by('-id')
+        prev_count = prev_posts.count()
+        if prev_count:
+            prev_post = prev_posts[0]
+
+        next_posts = posts.filter(pk__gt=post.pk).only('id').order_by('id')
+        next_count = next_posts.count()
+        if next_count:
+            next_post = next_posts[0]
+
+    template_data = {
+        'post': post,
+        'post_ord': post_ord,
+        'next_post': next_post,
+        'prev_post': prev_post,
+        'query_string': query_string,
+        'posts_count': posts_count,
+    }
+
+    if request.method == 'POST' and post:
+        return HttpResponseRedirect(f'{reverse("search_posts")}?post_id={post.pk}&q={urllib.parse.quote(query_string)}')
+
+    return render(request, 'search_posts/index.html', template_data)
