@@ -38,10 +38,11 @@ from django.utils import timezone
 from django.utils.html import strip_tags as strip_all_tags
 from django.views.decorators import csrf
 
+from askbot.auth import logout
 from askbot.utils.slug import slugify
 from askbot.utils.html import sanitize_html
 from askbot.utils.functions import encode_jwt
-from askbot.utils.transaction import defer_celery_task
+from askbot.utils.celery_utils import defer_celery_task
 from askbot.mail import send_mail
 from askbot.utils.translation import get_language
 from askbot.mail.messages import UnsubscribeLink
@@ -114,7 +115,7 @@ def delete_notifications(request):
     memo_set.delete()
     request.user.update_response_counts()
 
-def show_users(request, by_group=False, group_id=None, group_slug=None):
+def users_list(request, by_group=False, group_id=None, group_slug=None):
     """Users view, including listing of users by group"""
     if askbot_settings.GROUPS_ENABLED and not by_group:
         default_group = models.Group.objects.get_global_group()
@@ -251,7 +252,6 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         'group': group,
         'group_email_moderation_enabled': group_email_moderation_enabled,
         'group_openness_choices': group_openness_choices,
-        'page_class': 'users-page',
         'paginator_context' : paginator_context,
         'search_query' : search_query,
         'tab_id' : sort_method,
@@ -262,7 +262,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         'users' : users_page,
     }
 
-    return render(request, 'users.html', data)
+    return render(request, 'users/index.html', data)
 
 @csrf.csrf_protect
 def manage_account(request, subject, context):
@@ -294,9 +294,16 @@ def manage_account(request, subject, context):
         elif 'anonymize_account' in request.POST:
             if request.user.can_anonymize_account(subject):
                 subject.anonymize()
+                if request.user.pk == subject.pk:
+                    logout(request)
+                    message = _('Your account has been terminated. All content has been anonymized and remains accessible.')
+                    request.user.message_set.create(message=message)
                 return HttpResponseRedirect(subject.get_absolute_url())
             else:
-                msg = _('Sorry, something is not right here...')
+                if request.user.is_administrator() and request.user.pk == subject.pk:
+                    msg = _('Administrators cannot delete own accounts')
+                else:
+                    msg = _('Sorry, something is not right here...')
                 request.user.message_set.create(message=msg)
                 return HttpResponseRedirect(subject.get_absolute_url())
 
@@ -308,7 +315,7 @@ def manage_account(request, subject, context):
                 request.user.message_set.create(message=user_msg)
             else:
                 defer_celery_task(export_user_data, args=(subject.pk,))
-                if not django_settings.CELERY_ALWAYS_EAGER:
+                if not getattr(django_settings, 'CELERY_TASK_ALWAYS_EAGER', False):
                     exporting = True
 
     #todo: get backup download link -> context
@@ -316,6 +323,7 @@ def manage_account(request, subject, context):
     context['backup_file_names'] = subject.get_backup_file_names()
     context['exporting'] = exporting
     context['anon_user_name'] = models.get_name_of_anonymous_user()
+    context['tab_name'] = 'manage_account'
     return render(request, 'user_profile/user_manage_account.html', context)
 
 @decorators.ajax_only
@@ -444,7 +452,6 @@ def user_moderate(request, subject, context):
                                     )
     data = {
         'active_tab': 'users',
-        'page_class': 'user-profile-page',
         'tab_name': 'moderation',
         'page_title': _('moderate user'),
         'change_user_status_form': user_status_form,
@@ -522,7 +529,6 @@ def edit_user(request, id):
             user.show_country = form.cleaned_data['show_country']
             user.show_marked_tags = form.cleaned_data['show_marked_tags']
             user.save()
-            user.update_localized_profile(about=sanitize_html(form.cleaned_data['about']))
             # send user updated signal if full fields have been updated
             award_badges_signal.send(None,
                                      event='update_user_profile',
@@ -535,7 +541,6 @@ def edit_user(request, id):
 
     data = {
         'active_tab': 'users',
-        'page_class': 'user-profile-edit-page',
         'form' : form,
         'marked_tags_setting': askbot_settings.MARKED_TAGS_ARE_PUBLIC_WHEN,
         'support_custom_avatars': ('avatar' in django_settings.INSTALLED_APPS),
@@ -708,7 +713,6 @@ def user_stats(request, user, context):
 
     data = {
         'active_tab':'users',
-        'page_class': 'user-profile-page',
         'support_custom_avatars': ('avatar' in django_settings.INSTALLED_APPS),
         'show_moderation_warning': show_moderation_warning,
         'show_profile_info': show_profile_info,
@@ -785,7 +789,7 @@ def set_user_description(request):
 
     user = get_object_or_404(models.User, pk=user_id)
     if akismet_check_spam(description, request, user):
-        message = _('Spam was detected on your post, sorry if it was a mistake')
+        message = _('Spam was detected in the post')
         raise django_exceptions.PermissionDenied(message)
 
     if user_id == request.user.pk or request.user.is_admin_or_mod():
@@ -897,13 +901,12 @@ def user_recent(request, user, context):
 
     data = {
         'active_tab': 'users',
-        'page_class': 'user-profile-page',
         'tab_name' : 'recent',
         'page_title' : _('profile - recent activity'),
         'activities' : activities
     }
     context.update(data)
-    return render(request, 'user_profile/user_recent.html', context)
+    return render(request, 'user_profile/user_activity.html', context)
 
 #not a view - no direct url route here, called by `user_responses`
 @csrf.csrf_protect
@@ -928,7 +931,6 @@ def show_group_join_requests(request, user, context):
     data = {
         'active_tab':'users',
         'inbox_section': 'group-join-requests',
-        'page_class': 'user-profile-page',
         'tab_name' : 'join_requests',
         'page_title' : _('profile - moderation'),
         'groups_dict': groups_dict,
@@ -964,41 +966,6 @@ def user_responses(request, user, context):
         activity_types += (const.TYPE_ACTIVITY_MENTION,)
     elif section == 'join_requests':
         return show_group_join_requests(request, user, context)
-    elif section == 'messages':
-        #this is for the private messaging feature
-        if request.user != user:
-            if askbot_settings.ADMIN_INBOX_ACCESS_ENABLED == False:
-                raise Http404
-            elif not(request.user.is_moderator() or request.user.is_administrator()):
-                raise Http404
-
-        from askbot.deps.group_messaging.views import SendersList, ThreadsList
-        context.update(SendersList().get_context(request))
-        context.update(ThreadsList().get_context(request, user))
-        data = {
-            'inbox_threads_count': context['threads_count'],#a hackfor the inbox count
-            'active_tab':'users',
-            'page_class': 'user-profile-page',
-            'tab_name' : 'inbox',
-            'inbox_section': section,
-            'page_title' : _('profile - messages')
-        }
-        context.update(data)
-        if 'thread_id' in request.GET:
-            from askbot.deps.group_messaging.models import Message
-            from askbot.deps.group_messaging.views import ThreadDetails
-            try:
-                thread_id = request.GET['thread_id']
-                context.update(ThreadDetails().get_context(request, thread_id))
-                context['group_messaging_template_name'] = \
-                    'group_messaging/home_thread_details.html'
-            except Message.DoesNotExist:
-                raise Http404
-        else:
-            context['group_messaging_template_name'] = 'group_messaging/home.html'
-            #here we take shortcut, because we don't care about
-            #all the extra context loaded below
-        return render(request, 'user_inbox/messages.html', context)
     else:
         raise Http404
 
@@ -1075,7 +1042,6 @@ def user_responses(request, user, context):
 
     data = {
         'active_tab':'users',
-        'page_class': 'user-profile-page',
         'tab_name' : 'inbox',
         'inbox_section': section,
         'page_title' : _('profile - responses'),
@@ -1118,7 +1084,6 @@ def user_votes(request, user, context):
 
     data = {
         'active_tab':'users',
-        'page_class': 'user-profile-page',
         'tab_name' : 'votes',
         'page_title' : _('profile - votes'),
         'votes' : votes[:const.USER_VIEW_DATA_SIZE]
@@ -1172,7 +1137,6 @@ def user_reputation(request, user, context):
 
     data = {
         'active_tab':'users',
-        'page_class': 'user-profile-page',
         'tab_name': 'reputation',
         'page_title': _("Profile - User's Karma"),
         'latest_rep_changes': reputes[:100],
@@ -1209,7 +1173,6 @@ def user_favorites(request, user, context):
 
     data = {
         'active_tab':'users',
-        'page_class': 'user-profile-page',
         'tab_name' : 'favorites',
         'page_title' : _('profile - favorites'),
         'questions' : questions,
@@ -1276,7 +1239,6 @@ def user_select_languages(request, id=None, slug=None):
             'view_user': user,
             'languages_form': form,
             'tab_name': 'langs',
-            'page_class': 'user-profile-page',
         }
         return render(request, 'user_profile/user_languages.html', data)
 
@@ -1371,7 +1333,6 @@ def user_email_subscriptions(request, user, context):
     data = {
         'active_tab': 'users',
         'subscribed_tag_names': user.get_marked_tag_names('subscribed'),
-        'page_class': 'user-profile-page',
         'tab_name': 'email_subscriptions',
         'page_title': _('profile - email subscriptions'),
         'email_feeds_form': email_feeds_form,
@@ -1523,6 +1484,5 @@ def groups(request, id = None, slug = None):
         'user_can_add_groups': user_can_add_groups,
         'active_tab': 'groups',#todo vars active_tab and tab_name are too similar
         'tab_name': scope,
-        'page_class': 'groups-page'
     }
     return render(request, 'groups.html', data)
